from pathlib import Path

from .bytes import parse_stylesheet_bytes  # noqa
from .parser import (parse_declaration_list, parse_one_component_value,  # noqa
                     parse_one_declaration, parse_one_rule, parse_rule_list,
                     parse_stylesheet)
from .serializer import serialize, serialize_identifier  # noqa
from .tokenizer import parse_component_value_list  # noqa

VERSION = __version__ = (Path(__file__).parent / 'VERSION').read_text()



import sys

from setuptools import setup

if sys.version_info.major < 3:
    raise RuntimeError(
        'tinycss2 does not support Python 2.x anymore. '
        'Please use Python 3 or install an older version of tinycss2.')

setup()
